@@ -275,23 +275,6 @@ def to_lammps(
                 basex, basey, basez,
                 positions_splited[i],)
     basex, basey, basez = basex_, basey_, basez_
-    
-    if cart_dir=='Cartesian' or cart_dir=='cartesian':
-        pass
-    if cart_dir=='Direct' or cart_dir=='direct':
-        for p in range(len(positions_splited)):
-            for a in range(positions_splited[p].shape[0]):
-                x_ = positions_splited[p][a][0]
-                y_ = positions_splited[p][a][1]
-                z_ = positions_splited[p][a][2]
-                
-                x = x_*basex[0] + y_*basey[0] + z_*basez[0]
-                y = x_*basex[1] + y_*basey[1] + z_*basez[1]
-                z = x_*basex[2] + y_*basey[2] + z_*basez[2]
-                
-                positions_splited[p][a][0]  = x
-                positions_splited[p][a][1]  = y
-                positions_splited[p][a][2]  = z
 
     text = [name]
     text.append('\n')
@@ -344,7 +327,7 @@ def to_lammps(
                         '\n'
                         )
                 n += 1
-    else:
+    if 'charge' in args:
         n = 1
         for at in range(len(atoms_type)):
             for a in positions_splited[at]:
@@ -359,6 +342,20 @@ def to_lammps(
                         '\n'
                         )
                 n += 1
+    else:
+        n = 1
+        for at in range(len(atoms_type)):
+            for a in positions_splited[at]:
+                text.append(
+                        '   ' +
+                        str(n) + ' ' +
+                        str(at+1) + ' ' +
+                        str(a[0]) + ' ' + 
+                        str(a[1]) + ' ' + 
+                        str(a[2]) + ' ' + 
+                        '\n'
+                        )
+                n += 1
 
     text = "".join(text)
     file = open(fileout, 'w')
@@ -620,4 +617,145 @@ def vasp_to_runner_data_train(finput):
 
     file = open(finput + '/input.data', 'w')
     file.writelines(text)
-    file.close()
\ No newline at end of file
+    file.close()
+
+def fc(r, rm):
+    f = np.zeros_like(r)
+    for i in range(len(r)):
+        if r[i]<rm:
+            f[i] = 0.5*(np.cos(np.pi*r[i]/rm)+1)
+        else:
+            f[i] = 0
+    return f
+
+def g2(r, theta, f):
+    return np.exp(-theta*r**2)*f
+
+def r_05(r, rm, f):
+    return r[np.argmin(np.abs(g2(r, rm, f) - .5))]
+
+def theta(r, rm):
+    return (r**-2)*np.log(np.cos(np.pi*r/rm)+1)
+
+def acsf_creator(n_samples, rcut_factor, data_file):
+    file = open(data_file)
+    lines = file.readlines()
+    file.close()
+
+    head = lines[:1000]
+    idx = [h for h in range(len(head)) if 'end' in head[h]]
+    if len(idx)<1:
+        print('head to small!!!!!!')
+    step_l = idx[0]+1
+    atoms_l = step_l - 7
+    basis = head[1:4]
+    basis = np.array([b.split()[1:] for b in basis], dtype=float).T
+    basis_inv = np.linalg.inv(basis)
+    step_1 = head[4:step_l-3]
+
+    atom_labels = np.array([s.split()[4] for s in step_1])
+    atom_types = np.unique(atom_labels)
+
+    positions = np.array([s.split()[1:4] for s in step_1], dtype=float)
+    positions_fractional = np.dot(basis_inv, positions.T).T
+
+
+    positions_fractional_splited = []
+    for a in atom_types:
+        idx = np.where(atom_labels==a)[0]
+        positions_fractional_splited.append(positions_fractional[idx,:])
+
+    pairs = []
+    rmins = []
+    for at1 in range(len(atom_types)):
+        for at2 in range(len(atom_types)):
+            if at1>=at2:
+                a1 = positions_fractional_splited[at1]
+                a2 = positions_fractional_splited[at2]
+                r = []
+                for a in a1:
+                    a2_ = np.mod(a2-a+.5, 1) - .5
+                    a2_ = np.dot(basis, a2_.T).T
+                    r_ = np.sum(a2_**2, 1)**.5
+                    r.append(np.min(r_[r_>0]))
+                rmins.append(np.min(r))
+                pairs.append([atom_types[at1], atom_types[at2]])
+
+    rmax = np.min(rmins)*rcut_factor
+    symfunctions_text = []
+    for pair, rmin in zip(pairs, rmins):
+        r = np.linspace(0, rmax, 500)
+        f = fc(r, rmax)
+
+        r_05_max = r_05(r, 0, f)
+        r_05_min = rmin
+        r_05_step = (r_05_max - r_05_min)/(n_samples)
+
+        theta_all = []
+        for i in range(1, n_samples):
+            theta_all.append(theta(r_05_min + r_05_step*i, rmax))
+        theta_all.append(0)
+
+        for t in theta_all:
+            s = 'symfunction_short             '+pair[0]+' 2 '+pair[1]+'      '
+            s = s + "{:9.8f}".format(t)
+            s = s +'       0.00000000      '
+            s = s + "{:9.7f}".format(rmax)
+            symfunctions_text.append(s)
+        if pair[0]!=pair[1]:
+            for t in theta_all:
+                s = 'symfunction_short             '+pair[1]+' 2 '+pair[0]+'      '
+                s = s + "{:9.8f}".format(t)
+                s = s +'       0.00000000      '
+                s = s + "{:9.7f}".format(rmax)
+                symfunctions_text.append(s)
+
+
+    for at0 in range(len(atom_types)):
+        for at1 in range(len(atom_types)):
+            for at2 in range(len(atom_types)):
+                if at1>=at2:
+                    positions_shifted_0 = positions_fractional_splited[at0]
+                    positions_shifted_1 = positions_fractional_splited[at1]
+                    positions_shifted_2 = positions_fractional_splited[at2]
+                    r01 = np.array([])
+                    r02 = np.array([])
+                    r12 = np.array([])
+                    for p in range(positions_shifted_0.shape[0]):
+                        positions_shifted_1_ = np.mod(positions_shifted_1 - positions_shifted_0[p,:]+.5,1)-.5 
+                        positions_shifted_1_ = np.dot(basis, positions_shifted_1_.T).T
+                        positions_shifted_2_ = np.mod(positions_shifted_2 - positions_shifted_0[p,:]+.5,1)-.5 
+                        positions_shifted_2_ = np.dot(basis, positions_shifted_2_.T).T
+
+                        r01_ = np.sum(positions_shifted_1_**2, 1)**.5
+                        r02_ = np.sum(positions_shifted_2_**2, 1)**.5
+                        idx1 = np.where(r01_<rmax/1.8897259886)[0]
+                        idx2 = np.where(r02_<rmax/1.8897259886)[0]
+
+                        positions_shifted_1_ = positions_shifted_1_[idx1,:]
+                        positions_shifted_2_ = positions_shifted_2_[idx2,:]
+
+                        x12 = np.subtract.outer(positions_shifted_1_[:,0], positions_shifted_2_[:,0])
+                        y12 = np.subtract.outer(positions_shifted_1_[:,1], positions_shifted_2_[:,1])
+                        z12 = np.subtract.outer(positions_shifted_1_[:,2], positions_shifted_2_[:,2])
+                        r12_ = (x12**2 + y12**2 + z12**2)**.5
+                        r12_ = np.reshape(r12_, r12_.shape[0]*r12_.shape[1])
+                        r01 = np.append(r01, r01_)
+                        r02 = np.append(r02, r02_)
+                        r12 = np.append(r12, r12_)
+                    r = np.mean(r01)**2 + np.mean(r02)**2 + np.mean(r12)**2
+                    etha = np.log(2)/r
+
+                    for et in [etha, 0]:
+                        for z in [1,2,4,16]:
+                            s = 'symfunction_short             '+atom_types[at0]+' 3 '+atom_types[at1]+' '+atom_types[at2]+'      '
+                            s = s + "{:9.8f}".format(et)
+                            s = s +'      -1.00000000       '+"{:9.8f}".format(z)+'      '
+                            s = s + "{:9.7f}".format(rmax)
+                            symfunctions_text.append(s)
+                            s = 'symfunction_short             '+atom_types[at0]+' 3 '+atom_types[at1]+' '+atom_types[at2]+'      '
+                            s = s + "{:9.8f}".format(et)
+                            s = s +'       1.00000000       '+"{:9.8f}".format(z)+'      '
+                            s = s + "{:9.7f}".format(rmax)
+                            symfunctions_text.append(s)
+    return symfunctions_text
\ No newline at end of file
